---
title: <span class="badge object-type-scalar"></span> KiloVolt
---
# <span class="badge object-type-scalar"></span> KiloVolt

Energy: Kilovolt (kV)

## Definition

```python
# Energy: Kilovolt (kV)
KiloVolt: typing.Literal["kvolt"] = "kvolt"
```
